==> hoteldruid_3.0.1.orig.tar.gz: hoteldruid/includes/lang/en/inizio.php <==
<?php

switch ($messaggio) {

case "Menù principale dell'anno":             	$messaggio = "Main menu of year"; break;
case "Inserisci una nuova prenotazione":      	$messaggio = "Insert a new reservation"; break;
case "prenotazioni del mese di": 		$messaggio = "reservations in"; break;
case "visualizza": 				$messaggio = "view"; break;
case "Gennaio":                               	$messaggio = "January"; break;
case "Febbraio":                              	$messaggio = "February"; break;
case "Marzo":                                 	$messaggio = "March"; break;
case "Aprile":      				$messaggio = "April"; break;
case "Maggio":                           	$messaggio = "May"; break;
case "Giugno":                            	$messaggio = "June"; break;
case "Luglio":                            	$messaggio = "July"; break;
case "Agosto":  				$messaggio = "August"; break;
case "Settembre":  				$messaggio = "September"; break;
case "Ottobre":  				$messaggio = "October"; break;
case "Novembre":  				$messaggio = "November"; break;
case "Dicembre":  				$messaggio = "December"; break;
case "tabella con":  				$messaggio = "table with"; break;
case "tutte le prenotazioni":  			$messaggio = "all the reservations"; break;
case "le spese e le entrate":  			$messaggio = "incomes and expenses"; break;
case "i periodi e le tariffe":  		$messaggio = "the periods and the rates"; break;
case "tutti i clienti":  			$messaggio = "all the clients"; break;
case "le regole di assegnazione":  		$messaggio = "the assignment rules"; break;
case "Inserisci un nuovo cliente":		$messaggio = "Insert a new client"; break;
case "Spese ed entrate":  			$messaggio = "Incomes and expenses"; break;
case "disponibilità dal":  			$messaggio = "availability from"; break;
case "al":  					$messaggio = "to"; break;
case "per":  					$messaggio = "for"; break;
case "persone":	  				$messaggio = "people"; break;
case "controlla":  				$messaggio = "check"; break;
case "Inserisci o modifica i prezzi":  		$messaggio = "Insert or modify the prices"; break;
case "Inserisci o modifica le regole di assegnazione":  $messaggio = "Insert or modify the assignment rules"; break;
case "Configura e personalizza":	$messaggio = "Configure and customize"; break;
case "richiedi l'anno":  			$messaggio = "Go to year"; break;
case "vai":  					$messaggio = "go"; break;
case "Non esiste l'anno ":  			$messaggio = "The year "; break;
case " nel database":  				$messaggio = " does not exist in the database"; break;
case "Crea l'anno":  				$messaggio = "Create the year"; break;
case "Domenica":  				$messaggio = "Sunday"; break;
case "Lunedì":  				$messaggio = "Monday"; break;
case "Martedì":  				$messaggio = "Tuesday"; break;
case "Mercoledì":  				$messaggio = "Wednesday"; break;
case "Giovedì":  				$messaggio = "Thursday"; break;
case "Venerdì":  				$messaggio = "Friday"; break;
case "Sabato":	 		 		$messaggio = "Saturday"; break;
case "come giorno di inizio/fine locazione":	$messaggio = "as day of beginning/end rental"; break;
case "con periodi":  				$messaggio = "with"; break;
case "settimanali":  				$messaggio = "weekly periods"; break;
case "giornalieri":  				$messaggio = "daily periods"; break;
case "e prenotazioni da":  			$messaggio = "and reservations from"; break;
case "a":  					$messaggio = "to"; break;
case "anno successivo": 			$messaggio = "next year"; break;
case "anni successivi":  			$messaggio = "years later"; break;
case "Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi), privilegi degli utenti e regole d'assegnazione.":  $messaggio = "Import from previous year reservations, rates (inclusive the extra costs), users privileges and assignment rules."; break;
case "Anno ":  					$messaggio = "Year "; break;
case " creato":  				$messaggio = " created"; break;
case "Non ci sono periodi che riguardano il ":  $messaggio = "There are no periods regarding "; break;
case " nel ":  					$messaggio = " in "; break;
case ", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi aggiuntivi, caparra, nome delle tariffe, privilegi degli utenti e regole di assegnazione 2 e 3":	$messaggio = ", or the day of beginning/end rental was different, only data about extra costs, deposit, the names of the rates, users privileges and the assignment rules 2 and 3 have been imported"; break;
case "Attenzione</b></font>: i periodi del ":  	$messaggio = "Warning</b></font>: the periods of "; break;
case " finivano dopo quelli del ":  		$messaggio = " ended after the ones of "; break;
case " e vi erano":  				$messaggio = " and there were"; break;
case "prenotazioni che finivano dopo il limite posto al ":	$messaggio = "reservations that ended after the limit given for "; break;
case ", queste prenotazioni non sono state importate":	$messaggio = ", these reservations have not been imported"; break;
case "Anno già creato": 			$messaggio = "Year already created"; break;
case " Do":  					$messaggio = " Su"; break;
case " Lu":  					$messaggio = " Mo"; break;
case " Ma":  					$messaggio = " Tu"; break;
case " Me":  					$messaggio = " We"; break;
case " Gi":  					$messaggio = " Th"; break;
case " Ve":  					$messaggio = " Fr"; break;
case " Sa":  					$messaggio = " Sa"; break;
case "Gen":  					$messaggio = "Jan"; break;
case "Feb":  					$messaggio = "Feb"; break;
case "Mar":  					$messaggio = "Mar"; break;
case "Apr":  					$messaggio = "Apr"; break;
case "Mag":  					$messaggio = "May"; break;
case "Giu":  					$messaggio = "Jun"; break;
case "Lug":  					$messaggio = "Jul"; break;
case "Ago":  					$messaggio = "Aug"; break;
case "Set":  					$messaggio = "Sep"; break;
case "Ott":  					$messaggio = "Oct"; break;
case "Nov":  					$messaggio = "Nov"; break;
case "Dic":  					$messaggio = "Dec"; break;
case "Il formato dell'anno richiesto è sbagliato":	$messaggio = "The format of the requested year is wrong"; break;
case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":	$messaggio = "Months were wrongly selected, they have been inserted from January to December"; break;
case "N&deg;":  				$messaggio = "N&deg;"; break;
case "Cognome del cliente":  			$messaggio = "Client surname"; break;
case "Data iniziale":  				$messaggio = "Starting date"; break;
case "Data finale":  				$messaggio = "Ending date"; break;
case "Tariffa completa":  			$messaggio = "Complete rate"; break;
case "Da pagare":  				$messaggio = "To pay"; break;
case "Pers":  					$messaggio = "Peop"; break;
case "Registra":  				$messaggio = "Register"; break;
case "Entrata":  				$messaggio = "Check-in"; break;
case "Uscita":  				$messaggio = "Check-out"; break;
case "Entrata e pagato":  			$messaggio = "Check-in and paid"; break;
case "Uscita e pagato":  			$messaggio = "Check-out and paid"; break;
case "mostra tutte le date":  			$messaggio = "show all dates"; break;
case "Utente":  				$messaggio = "User"; break;
case "Esci":  					$messaggio = "Logout"; break;
case "Messaggi":  				$messaggio = "Messages"; break;
case "<span class=\"colred\">Avviso</span>: è consigliabile attendere fino al":	$messaggio = "<span class=\"colred\">Warning</span>: you are advised to wait until"; break;
case "per creare il nuovo anno, nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "before creating the new year, meanwhile you can add periods beyond"; break;
case "dalla":  					$messaggio = "from the"; break;
case "tabella con i periodi e le tariffe":  	$messaggio = "table with periods and rates"; break;
case "anche senza creare un nuovo anno":  	$messaggio = "even without creating a new year"; break;
case "Non ho i permessi di scrittura sulla cartella dati":	$messaggio = "I don't have write permissions on dati folder"; break;
case "le statistiche":  			$messaggio = "the statistics"; break;
case "inventario e magazzini":  		$messaggio = "inventory and stockrooms"; break;
case "obsoleti":  				$messaggio = "obsolete"; break;
case "Ultimo aggiornamento":  			$messaggio = "Last update"; break;
case "Aggiorna":  				$messaggio = "Update"; break;
case "i documenti salvati":  			$messaggio = "saved documents"; break;
case "Punto vendita":  				$messaggio = "Point of sale"; break;
case "Non ho i permessi per creare nuove tabelle nel database":	$messaggio = "I don't have permissions to create new tables in the database"; break;
case "Benvenuto a HOTELDRUID":  		$messaggio = "Welcome to HOTELDRUID"; break;
case "Scegli la lingua":  			$messaggio = "Choose the language"; break;
case "crea il database":  			$messaggio = "create database"; break;
case "Promemoria":  				$messaggio = "Reminder"; break;
case "Questo utente non ha i privilegi per creare nuovi anni":	$messaggio = "This user has no privileges to create new years"; break;
case "Avviso":  				$messaggio = "Warning"; break;
case "nel database sono ancora disponibili periodi solo per meno di":	$messaggio = "in the database there are still available periods for only less than"; break;
case "mesi":  					$messaggio = "months"; break;
case "OK, ho capito":  				$messaggio = "OK, got it"; break;
case "Crea Anno":  				$messaggio = "Create Year"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid_3.0.6.orig.tar.gz: hoteldruid/includes/lang/en/inizio.php <==
<?php

switch ($messaggio) {

case "Menù principale dell'anno":             	$messaggio = "Main menu of year"; break;
case "Inserisci una nuova prenotazione":      	$messaggio = "Insert a new reservation"; break;
case "prenotazioni del mese di": 		$messaggio = "reservations in"; break;
case "visualizza": 				$messaggio = "view"; break;
case "Gennaio":                               	$messaggio = "January"; break;
case "Febbraio":                              	$messaggio = "February"; break;
case "Marzo":                                 	$messaggio = "March"; break;
case "Aprile":      				$messaggio = "April"; break;
case "Maggio":                           	$messaggio = "May"; break;
case "Giugno":                            	$messaggio = "June"; break;
case "Luglio":                            	$messaggio = "July"; break;
case "Agosto":  				$messaggio = "August"; break;
case "Settembre":  				$messaggio = "September"; break;
case "Ottobre":  				$messaggio = "October"; break;
case "Novembre":  				$messaggio = "November"; break;
case "Dicembre":  				$messaggio = "December"; break;
case "tabella con":  				$messaggio = "table with"; break;
case "tutte le prenotazioni":  			$messaggio = "all the reservations"; break;
case "le spese e le entrate":  			$messaggio = "incomes and expenses"; break;
case "i periodi e le tariffe":  		$messaggio = "the periods and the rates"; break;
case "tutti i clienti":  			$messaggio = "all the clients"; break;
case "le regole di assegnazione":  		$messaggio = "the assignment rules"; break;
case "Inserisci un nuovo cliente":		$messaggio = "Insert a new client"; break;
case "Spese ed entrate":  			$messaggio = "Incomes and expenses"; break;
case "disponibilità dal":  			$messaggio = "availability from"; break;
case "al":  					$messaggio = "to"; break;
case "per":  					$messaggio = "for"; break;
case "persone":	  				$messaggio = "people"; break;
case "controlla":  				$messaggio = "check"; break;
case "Inserisci o modifica i prezzi":  		$messaggio = "Insert or modify the prices"; break;
case "Inserisci o modifica le regole di assegnazione":  $messaggio = "Insert or modify the assignment rules"; break;
case "Configura e personalizza":	$messaggio = "Configure and customize"; break;
case "richiedi l'anno":  			$messaggio = "Go to year"; break;
case "vai":  					$messaggio = "go"; break;
case "Non esiste l'anno ":  			$messaggio = "The year "; break;
case " nel database":  				$messaggio = " does not exist in the database"; break;
case "Crea l'anno":  				$messaggio = "Create the year"; break;
case "Domenica":  				$messaggio = "Sunday"; break;
case "Lunedì":  				$messaggio = "Monday"; break;
case "Martedì":  				$messaggio = "Tuesday"; break;
case "Mercoledì":  				$messaggio = "Wednesday"; break;
case "Giovedì":  				$messaggio = "Thursday"; break;
case "Venerdì":  				$messaggio = "Friday"; break;
case "Sabato":	 		 		$messaggio = "Saturday"; break;
case "come giorno di inizio/fine locazione":	$messaggio = "as day of beginning/end rental"; break;
case "con periodi":  				$messaggio = "with"; break;
case "settimanali":  				$messaggio = "weekly periods"; break;
case "giornalieri":  				$messaggio = "daily periods"; break;
case "e prenotazioni da":  			$messaggio = "and reservations from"; break;
case "a":  					$messaggio = "to"; break;
case "anno successivo": 			$messaggio = "next year"; break;
case "anni successivi":  			$messaggio = "years later"; break;
case "Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi), privilegi degli utenti e regole d'assegnazione.":  $messaggio = "Import from previous year reservations, rates (inclusive the extra costs), users privileges and assignment rules."; break;
case "Anno ":  					$messaggio = "Year "; break;
case " creato":  				$messaggio = " created"; break;
case "Non ci sono periodi che riguardano il ":  $messaggio = "There are no periods regarding "; break;
case " nel ":  					$messaggio = " in "; break;
case ", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi aggiuntivi, caparra, nome delle tariffe, privilegi degli utenti e regole di assegnazione 2 e 3":	$messaggio = ", or the day of beginning/end rental was different, only data about extra costs, deposit, the names of the rates, users privileges and the assignment rules 2 and 3 have been imported"; break;
case "Attenzione</b></font>: i periodi del ":  	$messaggio = "Warning</b></font>: the periods of "; break;
case " finivano dopo quelli del ":  		$messaggio = " ended after the ones of "; break;
case " e vi erano":  				$messaggio = " and there were"; break;
case "prenotazioni che finivano dopo il limite posto al ":	$messaggio = "reservations that ended after the limit given for "; break;
case ", queste prenotazioni non sono state importate":	$messaggio = ", these reservations have not been imported"; break;
case "Anno già creato": 			$messaggio = "Year already created"; break;
case " Do":  					$messaggio = " Su"; break;
case " Lu":  					$messaggio = " Mo"; break;
case " Ma":  					$messaggio = " Tu"; break;
case " Me":  					$messaggio = " We"; break;
case " Gi":  					$messaggio = " Th"; break;
case " Ve":  					$messaggio = " Fr"; break;
case " Sa":  					$messaggio = " Sa"; break;
case "Gen":  					$messaggio = "Jan"; break;
case "Feb":  					$messaggio = "Feb"; break;
case "Mar":  					$messaggio = "Mar"; break;
case "Apr":  					$messaggio = "Apr"; break;
case "Mag":  					$messaggio = "May"; break;
case "Giu":  					$messaggio = "Jun"; break;
case "Lug":  					$messaggio = "Jul"; break;
case "Ago":  					$messaggio = "Aug"; break;
case "Set":  					$messaggio = "Sep"; break;
case "Ott":  					$messaggio = "Oct"; break;
case "Nov":  					$messaggio = "Nov"; break;
case "Dic":  					$messaggio = "Dec"; break;
case "Il formato dell'anno richiesto è sbagliato":	$messaggio = "The format of the requested year is wrong"; break;
case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":	$messaggio = "Months were wrongly selected, they have been inserted from January to December"; break;
case "N&deg;":  				$messaggio = "N&deg;"; break;
case "Cognome del cliente":  			$messaggio = "Client surname"; break;
case "Data iniziale":  				$messaggio = "Starting date"; break;
case "Data finale":  				$messaggio = "Ending date"; break;
case "Tariffa completa":  			$messaggio = "Complete rate"; break;
case "Da pagare":  				$messaggio = "To pay"; break;
case "Pers":  					$messaggio = "Peop"; break;
case "Registra":  				$messaggio = "Register"; break;
case "Entrata":  				$messaggio = "Check-in"; break;
case "Uscita":  				$messaggio = "Check-out"; break;
case "Entrata e pagato":  			$messaggio = "Check-in and paid"; break;
case "Uscita e pagato":  			$messaggio = "Check-out and paid"; break;
case "mostra tutte le date":  			$messaggio = "show all dates"; break;
case "Utente":  				$messaggio = "User"; break;
case "Esci":  					$messaggio = "Logout"; break;
case "Messaggi":  				$messaggio = "Messages"; break;
case "<span class=\"colred\">Avviso</span>: è consigliabile attendere fino al":	$messaggio = "<span class=\"colred\">Warning</span>: you are advised to wait until"; break;
case "per creare il nuovo anno, nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "before creating the new year, meanwhile you can add periods beyond"; break;
case "dalla":  					$messaggio = "from the"; break;
case "tabella con i periodi e le tariffe":  	$messaggio = "table with periods and rates"; break;
case "anche senza creare un nuovo anno":  	$messaggio = "even without creating a new year"; break;
case "Non ho i permessi di scrittura sulla cartella dati":	$messaggio = "I don't have write permissions on dati folder"; break;
case "le statistiche":  			$messaggio = "the statistics"; break;
case "inventario e magazzini":  		$messaggio = "inventory and stockrooms"; break;
case "obsoleti":  				$messaggio = "obsolete"; break;
case "Ultimo aggiornamento":  			$messaggio = "Last update"; break;
case "Aggiorna":  				$messaggio = "Update"; break;
case "i documenti salvati":  			$messaggio = "saved documents"; break;
case "Punto vendita":  				$messaggio = "Point of sale"; break;
case "Non ho i permessi per creare nuove tabelle nel database":	$messaggio = "I don't have permissions to create new tables in the database"; break;
case "Benvenuto a HOTELDRUID":  		$messaggio = "Welcome to HOTELDRUID"; break;
case "Scegli la lingua":  			$messaggio = "Choose the language"; break;
case "crea il database":  			$messaggio = "create database"; break;
case "Promemoria":  				$messaggio = "Reminder"; break;
case "Questo utente non ha i privilegi per creare nuovi anni":	$messaggio = "This user has no privileges to create new years"; break;
case "Avviso":  				$messaggio = "Warning"; break;
case "nel database sono ancora disponibili periodi solo per meno di":	$messaggio = "in the database there are still available periods for only less than"; break;
case "mesi":  					$messaggio = "months"; break;
case "OK, ho capito":  				$messaggio = "OK, got it"; break;
case "Crea Anno":  				$messaggio = "Create Year"; break;
case "Nota":  					$messaggio = "Notice"; break;
case "l'anno":  				$messaggio = "year"; break;
case "verrà archiviato automaticamente il":  	$messaggio = "will be automatically archived on"; break;
case "nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "meanwhile you can add periods beyond"; break;
case "ricordarsi di tornare al":  		$messaggio = "remember to come back to"; break;
case "una volta conclusa la consultazione del":	$messaggio = "once finished consulting the"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
